==> flightgear_0.9.9.orig.tar.gz: FlightGear-0.9.9/src/FDM/UIUCModel/uiuc_map_fog.cpp <==
/********************************************************************** 
 
 FILENAME:     uiuc_map_fog.cpp 

---------------------------------------------------------------------- 

 DESCRIPTION:  initializes the fog map

----------------------------------------------------------------------
 
 STATUS:       alpha version

----------------------------------------------------------------------
 
 REFERENCES:   
 
----------------------------------------------------------------------
 
 HISTORY:      05/20/2001   initial release

----------------------------------------------------------------------
 
 AUTHOR(S):    Michael Savchenko       <savchenk@uiuc.edu>
 
----------------------------------------------------------------------
 
 VARIABLES:
 
----------------------------------------------------------------------
 
 INPUTS:       none
 
----------------------------------------------------------------------
 
 OUTPUTS:      none
 
----------------------------------------------------------------------
 
 CALLED BY:    uiuc_initializemaps.cpp
 
----------------------------------------------------------------------
 
 CALLS TO:     none
 
----------------------------------------------------------------------
 
 COPYRIGHT:    (C) 2000 by Michael Selig
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 USA or view http://www.gnu.org/copyleft/gpl.html.
 
**********************************************************************/


#include "uiuc_map_fog.h"


void uiuc_map_fog()
{
  fog_map["fog_segments"]	=	fog_segments_flag	;
  fog_map["fog_point"]		=	fog_point_flag		;
  
}

// end uiuc_map_fog.cpp

==> flightgear_2.0.0.orig.tar.gz: FlightGear-2.0.0/src/FDM/UIUCModel/uiuc_map_fog.cpp <==
/********************************************************************** 
 
 FILENAME:     uiuc_map_fog.cpp 

---------------------------------------------------------------------- 

 DESCRIPTION:  initializes the fog map

----------------------------------------------------------------------
 
 STATUS:       alpha version

----------------------------------------------------------------------
 
 REFERENCES:   
 
----------------------------------------------------------------------
 
 HISTORY:      05/20/2001   initial release

----------------------------------------------------------------------
 
 AUTHOR(S):    Michael Savchenko       <savchenk@uiuc.edu>
 
----------------------------------------------------------------------
 
 VARIABLES:
 
----------------------------------------------------------------------
 
 INPUTS:       none
 
----------------------------------------------------------------------
 
 OUTPUTS:      none
 
----------------------------------------------------------------------
 
 CALLED BY:    uiuc_initializemaps.cpp
 
----------------------------------------------------------------------
 
 CALLS TO:     none
 
----------------------------------------------------------------------
 
 COPYRIGHT:    (C) 2000 by Michael Selig
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

**********************************************************************/


#include "uiuc_map_fog.h"


void uiuc_map_fog()
{
  fog_map["fog_segments"]	=	fog_segments_flag	;
  fog_map["fog_point"]		=	fog_point_flag		;
  
}

// end uiuc_map_fog.cpp
